<?php

namespace App\Form\Type;

use App\Entity\Cotisation;
use App\Enum\MoyenEnum;
use App\Form\Type\CotisationInfosFormType;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\HiddenType;
use Symfony\Component\Form\Extension\Core\Type\MoneyType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\FormEvent;
use Symfony\Component\Form\FormEvents;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;

class AddCotisationFormType extends AbstractType
{
    protected $em;
    protected $tk;

    public function __construct(EntityManagerInterface $em, TokenStorageInterface $tk)
    {
        $this->em = $em;
        $this->tk = $tk;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $now = new \DateTime();
        $flux = $options['data'];
        if (empty($this->tk->getToken()) || empty($this->tk->getToken()->getUser()) || empty($this->tk->getToken()->getUser()->getId()) || empty($flux) || empty($flux->getExpediteur())) {
            throw new \Exception("[FLUX] Opération impossible ! Pas d'utilisateur connecté !");
        }
        $maxvalue = $flux->getExpediteur()->getCompte();
        $builder
            ->add('type', HiddenType::class, array(
                'data' => 'cotisation',
                'data_class' => null
            ))
            ->add('operateur', HiddenType::class, array(
                'data' => $this->tk->getToken()->getUser()->getId(),
                'data_class' => null,
                'entity_class' => User::class,
                'em' => $this->em
            ))
            ->add('reference', HiddenType::class, array(
                'label' => 'Reference :',
                'required' => true,
                'data' => 'Cotisation '.$now->format('Y')
            ))
            ->add('montant', MoneyType::class, array(
                'label' => 'Montant :',
                'required' => true
            ))
            ->add('moyen', ChoiceType::class, array(
                'required' => true,
                'choices' => MoyenEnum::getAvailableTypes(),
                'choice_label' => function ($choice) {
                    return MoyenEnum::getTypeName($choice);
                },
            ))
            ;
        ;
    }

    /**
     * {@inheritdoc}
     */
    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults(array(
            'data_class' => Cotisation::class,
            'cascade_validation' => true
        ));
    }


    public function getParent()
    {
        return FluxFormType::class;
    }

    public function getBlockPrefix()
    {
        return 'formCotisation';
    }
}
